SystemOrganization addCategory: #ConfigurationOfNautilus!

Object subclass: #ConfigurationOfNautilus
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNautilus'!

!ConfigurationOfNautilus commentStamp: '<historical>' prior: 0!
self loadDefault!

!ConfigurationOfNautilus class methodsFor: 'private' stamp: ''!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfNautilus class methodsFor: 'private' stamp: ''!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfNautilus class methodsFor: 'private' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNautilus class methodsFor: 'loadings' stamp: ''!
loadCore

	(self project version: #stable) load: 'core'! !

!ConfigurationOfNautilus class methodsFor: 'loadings' stamp: ''!
loadDefault

	(self project version: #stable) load: 'default'! !

!ConfigurationOfNautilus class methodsFor: 'loadings' stamp: ''!
loadRefactorings

	(self project version: #stable) load: 'refactorings'! !

!ConfigurationOfNautilus class methodsFor: 'loadings' stamp: ''!
loadRelease

	(self project version: #stable) load: 'release'! !

!ConfigurationOfNautilus class methodsFor: 'private' stamp: ''!
project

	^self new project! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package:  'Nautilus'.
		spec package: 'AST-Core'.
		
		spec repository: 'http://www.squeaksource.com/rb'.
		spec package: 'AST-Core'.
		spec package: 'Refactoring-Environment' with: [ spec requires: 'AST-Core' ]
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package:  'Nautilus'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package:  'Nautilus'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline22: spec 
	<version: '2.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package:  'Nautilus'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline23: spec 
	<version: '2.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [ spec requires: 'Refactoring-Environment' ].
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline24: spec 
	<version: '2.4-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [ spec requires: 'Refactoring-Environment' ].
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline30: spec 
	<version: '3.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package:  'Monticello'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [ spec requires: 'Refactoring-Environment' ].
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline31: spec 
	<version: '3.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package:  'Monticello'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [ spec requires: 'Refactoring-Environment' ].
	]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline32: spec 
	<version: '3.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package: 'PluggableTextMorphWithLimits'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package:  'Monticello'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec requires: 'Refactoring-Environment'.
			spec requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline33: spec 
	<version: '3.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'NautilusCommon'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package: 'PluggableTextMorphWithLimits'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package:  'Monticello'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec requires: 'NautilusCommon'.
			spec requires: 'Refactoring-Environment'.
			spec requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline34: spec 
	<version: '3.4-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ].
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package: 'PluggableTextMorphWithLimits'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec requires: 'NautilusCommon'.
			spec requires: 'Refactoring-Environment'.
			spec requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline35: spec 
	<version: '3.5-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ].
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package: 'PluggableTextMorphWithLimits'.
		spec package: 'NautilusTests'.
			
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec requires: 'NautilusCommon'.
			spec requires: 'Refactoring-Environment'.
			spec requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline36: spec 
	<version: '3.6-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec
			repository: 'http://www.squeaksource.com/DirtyExperiments';
			package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ];
			package: 'GroupManager';
			package:  'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits';
			package: 'NautilusTests'.
			
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec
				requires: 'NautilusCommon';
				requires: 'Refactoring-Environment';
				requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline37: spec 
	<version: '3.7-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec
			repository: 'http://www.squeaksource.com/DirtyExperiments';
			package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ];
			package: 'GroupManager';
			package:  'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec
				requires: 'NautilusCommon';
				requires: 'Refactoring-Environment';
				requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline38: spec 
	<version: '3.8-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec
			repository: 'http://www.squeaksource.com/rb';
			package: 'Refactoring-Environment'.
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ];
			package: 'GroupManager';
			package:  'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package:  'Nautilus' with: [
			spec
				requires: 'NautilusCommon';
				requires: 'Refactoring-Environment';
				requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline39: spec 
	<version: '3.9-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec
			repository: 'http://www.squeaksource.com/rb';
			package: 'Refactoring-Environment'.
		
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ];
			package: 'GroupManager';
			package:  'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		spec package:  'Nautilus' with: [
			spec
				requires: 'NautilusCommon';
				requires: 'Refactoring-Environment';
				requires: 'PluggableTextMorphWithLimits' ]]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline40: spec 
	<version: '4.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec
			repository: 'http://www.squeaksource.com/rb';
			package: 'Refactoring-Environment';
			package: 'AST-Core';
			package: 'AST-Semantic';
			package: 'Refactoring-Core' with: [ spec 
													requires: 'AST-Core';
													requires: 'AST-Semantic'];
			package: 'Refactoring-Changes' with: [ spec 
													requires: 'AST-Core';
													requires: 'AST-Semantic'];
			package: 'Refactoring-Critics' with: [ spec 
													requires: 'AST-Core';
													requires: 'AST-Semantic'];
			package: 'Refactoring-Spelling' with: [ spec 
													requires: 'AST-Core';
													requires: 'AST-Semantic'];
			package: 'Refactoring-Pharo-Platform' with: [ spec 
													requires: 'AST-Core';
													requires: 'AST-Semantic'].
		
		spec
			repository: 'http://ss3.gemstone.com/ss/Spec';
			package: 'Spec'.
		
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: 'Refactoring-Environment' ];
			package: 'GroupManager';
			package: 'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		spec package:  'Nautilus' with: [
			spec
				requires: 'NautilusCommon';
				requires: 'Refactoring-Environment';
				requires: 'PluggableTextMorphWithLimits' ].
		spec package: 'NautilusRefactoring' with: [ spec 
														requires: 'Refactoring-Core';
														requires: 'Refactoring-Changes';
														requires: 'Refactoring-Critics';
														requires: 'Refactoring-Pharo-Platform'].
	
		spec project: 'RPackage' with: [
			spec 
				className: 'ConfigurationOfRPackage';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/PharoTaskForces'].
		
		spec project: 'KeyMapping' with: [
			spec 
				className: 'ConfigurationOfKeymapping';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/ShortWays'].
	
		spec group: 'default' with: #('HistoryCollection' 'NautilusCommon' 'GroupManager' 'GroupManagerUI' 'PluggableTextMorphWithLimits' 'Refactoring-Environment' 'Nautilus').
		
		spec group: 'refactorings' with: #('default' 'AST-Core' 'AST-Semantic' 'Refactoring-Core' 'Refactoring-Changes' 'Refactoring-Critics' 'Refactoring-Spelling' 'Refactoring-Pharo-Platform' 'Spec' 'NautilusRefactoring')]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline41: spec 
	<version: '4.1-baseline'>
	
	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		
		"Dependencies"
		spec project: 'RPackage' with: [
			spec 
				className: 'ConfigurationOfRPackage';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/PharoTaskForces'].
			
		spec project: 'RBCore' with: [
			spec 
				className: 'ConfigurationOfRefactoringBrowser';
				versionString: #stable;
				loads: 'Core';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
			
		spec project: 'Refactoring-Environment' copyFrom: 'RBCore' with: [
				spec loads: #('Refactoring-Environment' ) ].

		spec project: 'KeyMapping' with: [
			spec 
				className: 'ConfigurationOfKeymapping';
				versionString: #'stable';
				loads: #('core' 'configurations' );
				repository: 'http://www.squeaksource.com/ShortWays'].
	
		spec project: 'Spec' with: [
			spec 
				className: 'ConfigurationOfSpec';
				versionString: #'stable';
				loads: #('default');
				repository: 'http://ss3.gemstone.com/ss/Spec'].		
		
		"Our own stuff"
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: #('Refactoring-Environment' 'KeyMapping') ];
			package: 'GroupManager';
			package: 'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		
		spec package:  'Nautilus' with: [
			spec requires: #('NautilusCommon' 'PluggableTextMorphWithLimits' 'RPackage') ].
			
		spec package: 'NautilusRefactoring' with: [ 
			spec requires: #('RBCore' 'Spec')].
		
		spec 
			group: 'default' with: #('core');
			group: 'core' with: #('HistoryCollection' 'GroupManager' 'GroupManagerUI' 'PluggableTextMorphWithLimits' 'Nautilus');
			group: 'refactorings' with: #('core' 'NautilusRefactoring')]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline42: spec 
	<version: '4.2-baseline'>
	
	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		
		"Dependencies"
		spec project: 'RPackage' with: [
			spec 
				className: 'ConfigurationOfRPackage';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/PharoTaskForces'].
			
		spec project: 'RBCore' with: [
			spec 
				className: 'ConfigurationOfRefactoringBrowser';
				versionString: #stable;
				loads: 'Core';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
			
		spec project: 'Refactoring-Environment' copyFrom: 'RBCore' with: [
				spec loads: #('Refactoring-Environment' ) ].

		spec project: 'KeyMapping' with: [
			spec 
				className: 'ConfigurationOfKeymapping';
				versionString: #'stable';
				loads: #('core' 'configurations' );
				repository: 'http://www.squeaksource.com/ShortWays'].
	
		spec project: 'Spec' with: [
			spec 
				className: 'ConfigurationOfSpec';
				versionString: #'stable';
				loads: #('default');
				repository: 'http://ss3.gemstone.com/ss/Spec'].		
					
		spec project: 'OCompletion' with: [
			spec 
				className: 'ConfigurationOfOCompletion';
				versionString: #'stable';
				loads: #('default');
				repository: 'http://www.squeaksource.com/MetacelloRepository'].	
		
		"Our own stuff"
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: #('Refactoring-Environment' 'KeyMapping') ];
			package: 'GroupManager';
			package: 'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		
		spec package:  'Nautilus' with: [
			spec requires: #('NautilusCommon' 'PluggableTextMorphWithLimits' 'RPackage') ].
			
		spec package: 'NautilusRefactoring' with: [ 
			spec requires: #('RBCore' 'Spec')].
		
		spec package: 'NautilusOCompletion' with: [
			spec requires: #('OCompletion')].
		
		spec 
			group: 'default' with: #('refactorings');
			group: 'core' with: #('HistoryCollection' 'GroupManager' 'GroupManagerUI' 'PluggableTextMorphWithLimits' 'Nautilus');
			group: 'refactorings' with: #('core' 'NautilusRefactoring');
			group: 'release' with: #('refactorings' 'NautilusOCompletion')]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baseline43: spec 
	<version: '4.3-baseline'>
	
	spec for: #pharo do: [
		
		"Info"
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Nautilus'.
		
		"Dependencies"
		spec project: 'RPackage' with: [
			spec 
				className: 'ConfigurationOfRPackage';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/PharoTaskForces'].
			
		spec project: 'RBCore' with: [
			spec 
				className: 'ConfigurationOfRefactoringBrowser';
				versionString: #stable;
				loads: 'Core';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
			
		spec project: 'Refactoring-Environment' copyFrom: 'RBCore' with: [
				spec loads: #('Refactoring-Environment' ) ].

		spec project: 'KeyMapping' with: [
			spec 
				className: 'ConfigurationOfKeymapping';
				versionString: #'stable';
				loads: #('core' 'configurations' );
				repository: 'http://www.squeaksource.com/ShortWays'].
	
		spec project: 'Spec' with: [
			spec 
				className: 'ConfigurationOfSpec';
				versionString: #'stable';
				loads: #('default');
				repository: 'http://ss3.gemstone.com/ss/Spec'].		
					
		spec project: 'OCompletion' with: [
			spec 
				className: 'ConfigurationOfOCompletion';
				versionString: #'stable';
				loads: #('default');
				repository: 'http://www.squeaksource.com/MetacelloRepository'].	
		
		spec project: 'Growl' with:[
			spec
				className: 'ConfigurationOfGrowl';
				versionString: #'stable';
				loads: #('default');
				repository: 'http://www.squeaksource.com/Growl' ].
		
		"Our own stuff"
		spec 
			package: 'HistoryCollection';
			package: 'NautilusCommon' with: [ spec requires: #('Refactoring-Environment' 'KeyMapping') ];
			package: 'GroupManager';
			package: 'GroupManagerUI';
			package: 'PluggableTextMorphWithLimits'.
			
		
		spec package:  'Nautilus' with: [
			spec requires: #('NautilusCommon' 'PluggableTextMorphWithLimits' 'RPackage' 'Growl') ].
			
		spec package: 'NautilusRefactoring' with: [ 
			spec requires: #('RBCore' 'Spec')].
		
		spec package: 'NautilusOCompletion' with: [
			spec requires: #('OCompletion')].
		
		spec 
			group: 'default' with: #('refactorings');
			group: 'core' with: #('HistoryCollection' 'GroupManager' 'GroupManagerUI' 'PluggableTextMorphWithLimits' 'Nautilus');
			group: 'refactorings' with: #('core' 'NautilusRefactoring');
			group: 'release' with: #('refactorings' 'NautilusOCompletion')]! !

!ConfigurationOfNautilus methodsFor: 'baselines' stamp: ''!
baselinealpha: spec 
	<version: 'alpha-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].	
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'Morphic-MorphTreeWidget-Extension'.
		
		spec repository: 'http://www.squeaksource.com/SwitchableTreeWidget'.
		spec package: 'SwitchableTreeWidget' with: [ spec requires: 'Morphic-MorphTreeWidget-Extension' ].
		
		spec repository: 'http://www.squeaksource.com/Nautilus'.
		spec package: 'HistoryCollection'.
		spec package: 'GroupManager'.
		spec package:  'GroupManagerUI'.
		spec package:  'Nautilus'.
		
		spec repository: 'http://www.squeaksource.com/DirtyExperiments'.
		spec package: 'Refactoring-Environment'
	]! !

!ConfigurationOfNautilus methodsFor: 'symbolics' stamp: ''!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '4.1'.
! !

!ConfigurationOfNautilus methodsFor: 'private' stamp: ''!
preloadKeyMappings

	Gofer new
		squeaksource: 'ShortWays';
		package: 'ConfigurationOfKeymapping';
		load.
	
	(ConfigurationOfKeymapping project version: #stable) load
		
	! !

!ConfigurationOfNautilus methodsFor: 'private' stamp: ''!
preloadRPackage

	Gofer new
		squeaksource: 'PharoTaskForces';
		package: 'ConfigurationOfRPackage';
		load.
		
	ConfigurationOfRPackage project  load: #'stable'
		
	! !

!ConfigurationOfNautilus methodsFor: 'private' stamp: ''!
preloads

	self preloadRPackage.
	self preloadKeyMappings.! !

!ConfigurationOfNautilus methodsFor: 'project' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfNautilus methodsFor: 'symbolics' stamp: ''!
stable: spec
	<symbolicVersion: #stable>

	spec for: #'common' version: '4.1'.! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version21: spec
	<version: '2.1' imports: #('2.1-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 2.1: Almost usable'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.8'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.3'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.5'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.2'.
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.8'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]		! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version24: spec
	<version: '2.4' imports: #('2.4-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 2.4: Add icons/shortcuts/multi-selection'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.15'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.3'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.12'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.25'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]		! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version30: spec
	<version: '3.0' imports: #('3.0-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 3.0: Beta phase'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.16'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.3'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.12'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Monticello' with: 'Monticello-BenjaminVanRyseghem.509'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.28'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]		! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version310: spec
	<version: '3.10' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.9 : improved tests
3.10 : merging'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 17:52'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-AlexandreBergel.8';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5';
			package: 'NautilusTests' with: 'NautilusTests-AlexandreBergel.2';
			package: 'Nautilus' with: 'Nautilus-AlexandreBergel.80'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version311: spec
	<version: '3.11' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.10 : merging'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 17:52'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-AlexandreBergel.8';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5';
			package: 'NautilusTests' with: 'NautilusTests-AlexandreBergel.2';
			package: 'Nautilus' with: 'Nautilus-AlexandreBergel.80'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version312: spec
	<version: '3.12' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.12 : Removing NautilusUI + cleans'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: ' 23 August 2011 1:34:57 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.11';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.18';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.85'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version313: spec
	<version: '3.13' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.13 : API'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: ' 23 August 2011 1:34:57 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.19';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.18';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.91'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version314: spec
	<version: '3.14' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.14 : Drag and drop'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: ' 23 August 2011 1:34:57 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.20';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.18';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.101'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version315: spec
	<version: '3.15' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.15 : Source code shortcuts'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '15 September 2011 5:21:40 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.21';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.19';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.8';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.103'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version316: spec
	<version: '3.16' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.16 : Minor Fixes'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '18 September 2011 2:32:40 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.21';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.19';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.8';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.105' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version317: spec
	<version: '3.17' imports: #('3.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.17 : Remove IdenticalTree'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '28 September 2011 3:36:40 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.21';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.19';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.9';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.113' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version318: spec
	<version: '3.18' imports: #('3.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.18 : Remove IdenticalTree'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '2 October 2011 4:36:40 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.22';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.19';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.9';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.6';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.113' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version319: spec
	<version: '3.19' imports: #('3.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.19 : New Announcements for Test'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '7 October 2011 12:36:40 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.24';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.19';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.9';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.6';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.121' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version31: spec
	<version: '3.1' imports: #('3.1-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 3.1: Ready for first release ?'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.4'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.12'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Monticello' with: 'Monticello-BenjaminVanRyseghem.509'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.34'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]		! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version320: spec
	<version: '3.20' imports: #('3.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.20 : Waiting for a change in AbstractTool to be integrated'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '7 October 2011 2:36:40 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.24';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.19';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.9';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.6';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.124' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version321: spec
	<version: '3.21' imports: #('3.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.21 : Widgets extraction'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '19 October 2011 5:07:36 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.32';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'NautilusTests' with: 'NautilusTests-BenjaminVanRyseghem.8';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.139' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version322: spec
	<version: '3.22' imports: #('3.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.22 : Waiting for issue number (5201)'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '19 January 2012 2:43:52 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-BenjaminVanRyseghem.10';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.36';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.154' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version323: spec
	<version: '3.23' imports: #('3.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.23 : New baseline to use for the moment Luka''s RB environment'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '30 January 2012 4:32:52 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-lr.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.36';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.160' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version324: spec
	<version: '3.24' imports: #('3.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.24 : Waiting for Issue 5257 to be integrated'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '7 February 2012 9:25:36 am'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-lr.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.36';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.161' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version32: spec
	<version: '3.2' imports: #('3.2-baseline')>

	spec for: #common do: [
		spec preLoadDoIt: #preloadRPackage.
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 3.2: Few cool stuff added'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.5'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Monticello' with: 'Monticello-BenjaminVanRyseghem.520'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.3' .
		
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.46'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version33: spec
	<version: '3.3' imports: #('3.2-baseline')>

	spec for: #common do: [
		spec preLoadDoIt: #preloadRPackage.
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 3.3: Plugins + History + Refactorizations'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.6'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Monticello' with: 'Monticello-BenjaminVanRyseghem.520'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.3' .
		
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.47'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version34: spec
	<version: '3.4' imports: #('3.2-baseline')>

	spec for: #common do: [
		spec preLoadDoIt: #preloadRPackage.
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 3.4: Refactorizations'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Monticello' with: 'Monticello-BenjaminVanRyseghem.520'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5' .
		
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.61'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version35: spec
	<version: '3.5' imports: #('3.2-baseline')>

	spec for: #common do: [
		spec preLoadDoIt: #preloadRPackage.
		spec blessing: #development.
		spec author: 'BenjaminVanRyseghem'.
		spec description: 'Version 3.5: Refactorizations'.
	].
	
	spec for: #pharo do: [ 
		spec package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18'.
		spec package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7'.
		spec package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17'.
		spec package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7'.
		
		spec package: 'Monticello' with: 'Monticello-BenjaminVanRyseghem.520'.
		
		spec package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1'.
		
		spec package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5' .
		
		spec package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.3'.
		spec package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.66'.
	
		spec package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9'.
		spec package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'.
			
	]! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version36: spec
	<version: '3.6' imports: #('3.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Version 3.6: Refactorizations
3.6 : Some improvement and bug fixing'.
		spec preLoadDoIt: #'preloadRPackage'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 16:24'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.6';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.76';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'Refactoring-Tests-Environment' with: 'Refactoring-Tests-Environment-StephaneDucasse.2'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version37: spec
	<version: '3.7' imports: #('3.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.6 : Some improvement and bug fixing
3.7 : Added a comment and allow Cmd-t for running the test on a group (but classes have to be selected)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 16:35'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.6';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-AlexandreBergel.77'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version38: spec
	<version: '3.8' imports: #('3.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.7 : Added a comment and allow Cmd-t for running the test on a group (but classes have to be selected)
3.8 : Added a shortcut Cmd-j to jump to a unit test'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 17:28'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-AlexandreBergel.8';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5';
			package: 'Nautilus' with: 'Nautilus-AlexandreBergel.78'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version39: spec
	<version: '3.9' imports: #('3.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '3.8 : Added a shortcut Cmd-j to jump to a unit test
3.9 : improved tests'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2011 17:31'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Morphic-MorphTreeWidget-Extension' with: 'Morphic-MorphTreeWidget-Extension-BenjaminVanRyseghem.1';
			package: 'SwitchableTreeWidget' with: 'SwitchableTreeWidget-BenjaminVanRyseghem.18';
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-StephaneDucasse.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-AlexandreBergel.8';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.17';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.7';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.5';
			package: 'NautilusTests' with: 'NautilusTests-AlexandreBergel.2';
			package: 'Nautilus' with: 'Nautilus-AlexandreBergel.78'. ].
! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version401: spec
	<version: '4.01' imports: #('3.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '4.01 : Introducing KeyMappings'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '20 February 2012 5:48:16 pm'.
		spec preLoadDoIt: #'preloads'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-lr.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.44';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.184' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version402: spec
	<version: '4.02' imports: #('4.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '4.02 : New baseline to have a better configuration'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '20 February 2012 5:48:16 pm'.
		spec preLoadDoIt: #'preloads'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.44';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.185';
			package: 'Refactoring-Core';
			package: 'Refactoring-Changes';
			package: 'Refactoring-Critics';
			package: 'Refactoring-Pharo-Platform';
			package: 'Spec';
			package: 'NautilusRefactoring' with: 'NautilusRefactoring-BenjaminVanRyseghem.11'].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version403: spec
	<version: '4.03' imports: #('4.1-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '4.03 : New baseline to have a better configuration';
			author: 'MarianoMartinezPeck';
			timestamp: '20 February 2012 5:48:16 pm'.
		
		spec 
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.48';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.21';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.11';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.204';
			package: 'NautilusRefactoring' with: 'NautilusRefactoring-BenjaminVanRyseghem.13' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version404: spec
	<version: '4.04' imports: #('4.2-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '4.04 : Better handling of Monticello Packages';
			author: 'BenjaminVanRyseghem';
			timestamp: '2/25/2012 21:01'.
		
		spec 
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.49';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.22';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.11';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.219';
			package: 'NautilusRefactoring' with: 'NautilusRefactoring-BenjaminVanRyseghem.16';
			package: 'NautilusOCompletion' with: 'NautilusOCompletion-BenjaminVanRyseghem.1' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: ''!
version40: spec
	<version: '4.0' imports: #('3.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '4.0 : Huge optimizatin (x10)'.
		spec author: 'BenjaminVanRyseghem'.
		spec timestamp: '7 February 2012 11:20:16 pm'.
		spec preLoadDoIt: #'preloadRPackage'.].

	spec for: #'pharo' do: [
		spec 
			package: 'Refactoring-Environment' with: 'Refactoring-Environment-lr.9';
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.7';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.41';
			package: 'GroupManager' with: 'GroupManager-BenjaminVanRyseghem.20';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.10';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-DamienPollet.7';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.179' ].! !

!ConfigurationOfNautilus methodsFor: 'versions' stamp: 'BenjaminVanRyseghem 3/22/2012 13:07'!
version41: spec
	<version: '4.1' imports: #('4.3-baseline' )>

	spec for: #'pharo' do: [
		
		spec 
			blessing: #'development';
			description: '4.1 : Fix Monticello versionning / Introduce NotificationManager';
			author: 'BenjaminVanRyseghem';
			timestamp: '3/1/2012 20:22'.
		
		spec 
			package: 'HistoryCollection' with: 'HistoryCollection-BenjaminVanRyseghem.9';
			package: 'NautilusCommon' with: 'NautilusCommon-BenjaminVanRyseghem.56';
			package: 'GroupManager' with: 'GroupManager-DamienPollet.25';
			package: 'GroupManagerUI' with: 'GroupManagerUI-BenjaminVanRyseghem.12';
			package: 'PluggableTextMorphWithLimits' with: 'PluggableTextMorphWithLimits-BenjaminVanRyseghem.8';
			package: 'Nautilus' with: 'Nautilus-BenjaminVanRyseghem.237';
			package: 'NautilusRefactoring' with: 'NautilusRefactoring-BenjaminVanRyseghem.19';
			package: 'NautilusOCompletion' with: 'NautilusOCompletion-BenjaminVanRyseghem.1' ].! !
